@@ -26,6 +26,7 @@
 #include "gtkdatesel.h"
 
 static GSList *strings;
+static GSList *day_events[24], *untimed_events;
 static GtkWidget *day_list;
 static GtkWidget *datesel;
 static GtkAdjustment *scroll_adjustment;
@@ -98,9 +99,9 @@ selection_made (GtkWidget      *clist,
       else 
 	{
 	  char *t;
-	  gtk_clist_get_text (GTK_CLIST (clist), row, 0, &t);
 	  localtime_r (&viewtime, &tm);
-	  strptime (t, TIMEFMT, &tm);
+	  if (gtk_clist_get_text (GTK_CLIST (clist), row, 0, &t))
+	    strptime (t, TIMEFMT, &tm);
 	  gtk_widget_show_all (new_event (mktime (&tm), 1));
 	}
     }
@@ -109,10 +110,12 @@ selection_made (GtkWidget      *clist,
       // set the default event time to match the selected row
       struct tm tm;
       char *t;
-      gtk_clist_get_text (GTK_CLIST (clist), row, 0, &t);
-      localtime_r (&viewtime, &tm);
-      strptime (t, TIMEFMT, &tm);
-      viewtime = mktime (&tm);
+      if (gtk_clist_get_text (GTK_CLIST (clist), row, 0, &t))
+	{
+	  localtime_r (&viewtime, &tm);
+	  strptime (t, TIMEFMT, &tm);
+	  viewtime = mktime (&tm);
+	}
     }
 }
 
@@ -124,13 +127,10 @@ day_view_update ()
   struct tm tm_start, tm_end;
   char buf[10];
   gchar *line_info[2];
-  GSList *day_events[24], *untimed_events;
   GSList *iter;
   guint i, width = 0, widget_width;
-#if GTK_MAJOR_VERSION >= 2
   PangoLayout *pl = gtk_widget_create_pango_layout (GTK_WIDGET (day_list), NULL);
   PangoRectangle pr;
-#endif
   double pos;
      
   widget_width = day_list->allocation.width;
@@ -186,6 +186,8 @@ day_view_update ()
   tm_end.tm_min = 59;
   tm_end.tm_sec = 0;
   end = mktime (&tm_end);
+  
+  if (untimed_events) event_db_list_destroy (untimed_events);
   untimed_events = event_db_untimed_list_for_period (start, end, TRUE);
 
   for (iter = untimed_events; iter; iter = iter->next)
@@ -198,9 +200,7 @@ day_view_update ()
       line_info[1] = text;
 
       gtk_clist_append (GTK_CLIST (day_list), line_info);
-      if (ev->flags & FLAG_CLONE) 
-	  gtk_clist_set_row_data (GTK_CLIST (day_list), row, event_db_find_by_uid (ev->uid));
-      else gtk_clist_set_row_data (GTK_CLIST (day_list), row, ev);
+      gtk_clist_set_row_data (GTK_CLIST (day_list), row, ev);
       row++;
     }
   
@@ -218,6 +218,7 @@ day_view_update ()
       tm_end.tm_sec = 0;
       end = mktime (&tm_end);
 
+      if (day_events[hour]) event_db_list_destroy (day_events[hour]);
       day_events[hour] = event_db_untimed_list_for_period (start, end-1, FALSE);
       
       for (iter = day_events[hour]; iter; iter = iter->next)
@@ -259,27 +260,21 @@ day_view_update ()
       line_info[1] = text;
       line_info[0] = buf;
 
-#if GTK_MAJOR_VERSION < 2     
-      w = gdk_string_width (time_style->font, buf);
-#else
       pango_layout_set_text (pl, buf, strlen (buf));
       pango_layout_get_pixel_extents (pl, &pr, NULL);
       w = pr.width;
-#endif
+
       if (w > width) width = w;
 	
       gtk_clist_append (GTK_CLIST (day_list), line_info);
+      gtk_clist_set_row_data (GTK_CLIST (day_list), row, ev);
 
       if (ev) 
 	{
 	  GdkPixmap *pmap;
 	  GdkBitmap *bmap;
 	  
-	  if (ev->flags & FLAG_CLONE) 
-	    gtk_clist_set_row_data (GTK_CLIST (day_list), row, event_db_find_by_uid (ev->uid));
-	  else gtk_clist_set_row_data (GTK_CLIST (day_list), row, ev);
-    	    
-	  if ((ev->flags & FLAG_ALARM) && (ev->flags & FLAG_RECUR))
+    	  if ((ev->flags & FLAG_ALARM) && ev->recur)
 	    {
 	      if (gpe_find_icon_pixmap ("bell_recur", &pmap, &bmap))
 		gtk_clist_set_pixtext (GTK_CLIST (day_list), row, 1, text, 5,
@@ -291,7 +286,7 @@ day_view_update ()
 		gtk_clist_set_pixtext (GTK_CLIST (day_list), row, 1, text, 5,
 				       pmap, bmap);
 	    }
-	  else if (ev->flags & FLAG_RECUR)
+	  else if (ev->recur)
 	    {
 	      if (gpe_find_icon_pixmap ("recur", &pmap, &bmap))
 		gtk_clist_set_pixtext (GTK_CLIST (day_list), row, 1, text, 5,
@@ -328,18 +323,12 @@ day_view_update ()
 	  g_slist_append (strings, line_info[1]);
 
           gtk_clist_append (GTK_CLIST (day_list), line_info);
-	  if (ev->flags & FLAG_CLONE) 
-	    gtk_clist_set_row_data (GTK_CLIST (day_list), row, event_db_find_by_uid (ev->uid));
-	  else gtk_clist_set_row_data (GTK_CLIST (day_list), row, ev);
-
+	  gtk_clist_set_row_data (GTK_CLIST (day_list), row, ev);
 	  gtk_clist_set_cell_style (GTK_CLIST (day_list), row, 1, dark_style);
 	  row++;
        } 
     }
 
-  for (hour = 0; hour <= 23; hour++)
-    event_db_list_destroy (day_events[hour]);
-
   for (i = 0; i < row; i++)
     gtk_clist_set_cell_style (GTK_CLIST (day_list), i, 0, time_style);
 
@@ -348,9 +337,7 @@ day_view_update ()
 
   gtk_clist_thaw (GTK_CLIST (day_list));
 
-#if GTK_MAJOR_VERSION >= 2
   g_object_unref (pl);
-#endif
   
   return TRUE;
 }
