@@ -30,7 +30,7 @@
 #include "future_view.h"
 #include "month_view.h"
 
-#include <libdm.h>
+#include <libdisplaymigration/displaymigration.h>
 
 #define _(_x) gettext (_x)
 
@@ -59,6 +59,7 @@ static GtkWidget *day_button, *week_button, *month_button, *future_button;
 
 guint window_x = 240, window_y = 310;
 
+guint week_offset = 0;
 gboolean week_starts_monday = TRUE;
 gboolean day_view_combined_times;
 
@@ -127,13 +128,6 @@ new_view (GtkWidget *widget)
     } while (w != NULL);
 }
 
-void
-set_day_view (void)
-{
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (day_button), TRUE);
-  new_view (day);
-}
-
 static void
 new_appointment (void)
 {
@@ -148,6 +142,15 @@ set_today(void)
   update_current_view ();
 }
 
+void
+set_time_and_day_view(time_t selected_time)
+{
+  viewtime=selected_time;
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (day_button), TRUE);
+  new_view (day);
+  update_current_view();
+}
+
 static void
 button_toggled (GtkWidget *widget, gpointer data)
 {
@@ -187,7 +190,7 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 
-  libdm_init ();
+  displaymigration_init ();
 
   if (event_db_start () == FALSE)
     exit (1);
@@ -237,10 +240,10 @@ main (int argc, char *argv[])
 
   main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (main_window), _("Calendar"));
-  g_signal_connect (G_OBJECT (main_window), "destroy",
+  g_signal_connect (G_OBJECT (main_window), "delete-event",
                     G_CALLBACK (gpe_cal_exit), NULL);
 
-  libdm_mark_window (main_window);
+  displaymigration_mark_window (main_window);
 
   gtk_widget_realize (main_window);
 
@@ -330,7 +333,8 @@ main (int argc, char *argv[])
 
   update_all_views ();
 
-  set_day_view ();
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (day_button), TRUE);
+  new_view (day);
 
   gtk_main ();
 
